<?php
/**
 * @file Primarily handles the return flow from Amazon Payments.
 */

// Handles a complete Flexible Payments Service sale.
function mp_amazon_fps_complete($order) {
  // Verify that Amazon Payments issued the redirect to the completion URL.
  module_load_include('inc', 'uc_amazonpayments', 'uc_amazonpayments.pages');
  $fps_config = array('ServiceURL' => _uc_amazonpayments_fps_api_url());
  $payment_authorized = uc_amazonpayments_verify_signature();
  if ($payment_authorized) {
    module_load_include('inc', 'mp_amazon_fps', 'mp_amazon_fps.payment');
    amazon_fps_include('fps');
    // Store the multi-use token in the order data
    $order->data['mp_amazon_fps_multi_use_token'] = check_plain($_GET['tokenID']);
    uc_order_save($order);

    // Retrieve the order total per seller
    $order_sellers = _mp_amazon_fps_order_sellers($order);

    foreach ($order_sellers as $uid => $seller) {
      // Issue a Pay request to Amazon Payments. This will also transmit an IPN
      // to the site.
      // Build the request to send to the Amazon FPS API
      $authorization = mp_amazon_fps_authorization_load($uid);
      $request = array(
        'CallerReference' => check_plain($_GET['callerReference']) . "-{$uid}",
        'SenderTokenId' => check_plain($_GET['tokenID']),
        'RecipientTokenId' => $authorization->recipient_token_id,
        'TransactionAmount' => array(
          'CurrencyCode' => 'USD',
          'Value' => $seller->seller_total,
        ),
      );
      // Allow other modules to change the contents of the Pay request
      drupal_alter('mp_amazon_fps_payment', $request, $order, $seller);
      $fps = amazon_fps_fps_pay($request, $fps_config);
    }
  }
  _uc_amazonpayments_complete($order);
}

